# file-cryptor
File cryptor helps encrypt and decrypt files. So we may protect our privacy from peeping eyes like cloud storage providers.

TODO:

- Text encryption / decryption.
- Password generation, like https://oneshallpass.com/
- password manager
